@@ -47,18 +47,18 @@
 #else
 #include <sys/wait.h>
 #include <sys/signal.h>
-#endif /* __MINGW32__ */
+#endif				/* __MINGW32__ */
 
 #include "globals.h"
 #include "sound.h"
 #include "prefs.h"
 #include "plugin_api.h"
 
-int clean_pid(void * dummy);	/* util.h */
+int clean_pid(void *dummy);	/* util.h */
 
 #ifdef ESD_SOUND
 #include <esd.h>
-#endif	/* ARTS_SOUND */
+#endif				/* ARTS_SOUND */
 
 #ifdef ARTS_SOUND
 #include <string.h>
@@ -73,30 +73,28 @@ int clean_pid(void * dummy);	/* util.h */
  * This is KDE bug #34541, known to be fixed with arts >= 1.1.3
  */
 
-#endif	/* ARTS_SOUND */
+#endif				/* ARTS_SOUND */
 
-static int (*play_soundfile)(gchar *soundfile);
-static void (*shutdown_sounddrv)();
+static int (*play_soundfile) (gchar *soundfile);
+static void (*shutdown_sounddrv) ();
 
 static int play_audio(gchar *soundfile)
 {
 	int fd;
-	struct stat info;	
-	char * buf;
-	char * audio_device;
+	struct stat info;
+	char *buf;
+	char *audio_device;
 
-	fd = open(soundfile,O_RDONLY);
-	if (fd <= 0)
-	{
+	fd = open(soundfile, O_RDONLY);
+	if (fd <= 0) {
 		eb_debug(DBG_CORE, "Cannot open file %s\n", soundfile);
 		return FALSE;
 	}
 	fstat(fd, &info);
 	buf = alloca(info.st_size);
-	read(fd,buf,24);
-	read(fd,buf,info.st_size-24);
+	read(fd, buf, 24);
+	read(fd, buf, info.st_size - 24);
 	close(fd);
-	eb_debug(DBG_CORE, "File is %ld bytes\n", info.st_size);
 
 	audio_device = getenv("AUDIODEV");
 	if (audio_device == NULL) {
@@ -104,12 +102,13 @@ static int play_audio(gchar *soundfile)
 		audio_device = "/dev/audio";
 	}
 
-	eb_debug(DBG_CORE, "sending to %s\n", audio_device);
+	eb_debug(DBG_CORE, "File is %ld bytes. Sending to %s\n", info.st_size,
+		audio_device);
 
 	fd = open(audio_device, O_WRONLY | O_EXCL);
 	if (fd < 0)
 		return FALSE;
-	write(fd, buf, info.st_size-24);
+	write(fd, buf, info.st_size - 24);
 	close(fd);
 
 	return TRUE;
@@ -117,9 +116,9 @@ static int play_audio(gchar *soundfile)
 
 static int can_play_audio()
 {
-        /* FIXME check for write access and such. */
+	/* FIXME check for write access and such. */
 	/* do not change from return 1 for WIN32 */
-        return 1;
+	return 1;
 
 }
 
@@ -144,37 +143,39 @@ static int can_play_audio()
 ** Output: 8 bit ulaw sample
 */
 
-#define ZEROTRAP    /* turn on the trap as per the MIL-STD */
-#define BIAS 0x84   /* define the add-in bias for 16 bit samples */
+#define ZEROTRAP		/* turn on the trap as per the MIL-STD */
+#define BIAS 0x84		/* define the add-in bias for 16 bit samples */
 #define CLIP 32635
 
 static unsigned char linear2ulaw(int sample)
 {
-	static int exp_lut[256] = {0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,
-                	     4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
-                	     5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
-                	     5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
-                	     6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
-                	     6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
-                	     6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
-                	     6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
-                	     7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-                	     7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-                	     7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-                	     7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-                	     7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-                	     7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-                	     7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-                	     7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7};
+	static int exp_lut[256] =
+		{ 0, 0, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3,
+		4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
+		5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
+		5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
+		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
+		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
+		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
+		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7
+	};
 	int sign, exponent, mantissa;
 	unsigned char ulawbyte;
 
 	/* Get the sample into sign-magnitude. */
-	sign = (sample >> 8) & 0x80;		/* set aside the sign */
-	if (sign != 0) 
-		sample = -sample;		/* get magnitude */
-	if (sample > CLIP) 
-		sample = CLIP;		/* clip the magnitude */
+	sign = (sample >> 8) & 0x80;	/* set aside the sign */
+	if (sign != 0)
+		sample = -sample;	/* get magnitude */
+	if (sample > CLIP)
+		sample = CLIP;	/* clip the magnitude */
 
 	/* Convert from 16 bit linear to ulaw. */
 	sample = sample + BIAS;
@@ -182,11 +183,11 @@ static unsigned char linear2ulaw(int sample)
 	mantissa = (sample >> (exponent + 3)) & 0x0F;
 	ulawbyte = ~(sign | (exponent << 4) | mantissa);
 #ifdef ZEROTRAP
-	if (ulawbyte == 0) 
+	if (ulawbyte == 0)
 		ulawbyte = 0x02;	/* optional CCITT trap */
 #endif
 
-	return(ulawbyte);
+	return (ulawbyte);
 }
 
 #if HAVE_LIBAUDIOFILE
@@ -209,7 +210,7 @@ static unsigned char linear2ulaw(int sample)
 ** Input: 8 bit ulaw sample
 ** Output: signed 16 bit linear sample
 */
-int _af_ulaw2linear (unsigned char ulawbyte);
+int _af_ulaw2linear(unsigned char ulawbyte);
 
 #else
 
@@ -229,9 +230,9 @@ int _af_ulaw2linear (unsigned char ulawbyte);
 ** Output: signed 16 bit linear sample
 ** Z-note -- this is from libaudiofile.  Thanks guys!
 */
-static int _af_ulaw2linear (unsigned char ulawbyte)
+static int _af_ulaw2linear(unsigned char ulawbyte)
 {
-	static int exp_lut[8] = {0,132,396,924,1980,4092,8316,16764};
+	static int exp_lut[8] = { 0, 132, 396, 924, 1980, 4092, 8316, 16764 };
 	int sign, exponent, mantissa, sample;
 
 	ulawbyte = ~ulawbyte;
@@ -239,11 +240,12 @@ static int _af_ulaw2linear (unsigned char ulawbyte)
 	exponent = (ulawbyte >> 4) & 0x07;
 	mantissa = ulawbyte & 0x0F;
 	sample = exp_lut[exponent] + (mantissa << (exponent + 3));
-	if (sign != 0) sample = -sample;
-		return(sample);
+	if (sign != 0)
+		sample = -sample;
+	return (sample);
 }
 
-#endif	/* HAVE_LIBAUDIOFILE */
+#endif				/* HAVE_LIBAUDIOFILE */
 
 #ifdef ESD_SOUND
 
@@ -258,11 +260,15 @@ static int play_esd_file(gchar *soundfile)
 	esd_stat = esd_play_file(NULL, soundfile, 1);
 	if (!esd_stat) {
 		if (errno == ENOENT) {
-	    		eb_debug(DBG_CORE, "Ayttm: File not found - file = \"%s\"\n", soundfile);
+			eb_debug(DBG_CORE,
+				"Ayttm: File not found - file = \"%s\"\n",
+				soundfile);
 		} else {
-		    	eb_debug(DBG_CORE, "Ayttm: Esd play file failed with code %d\n", errno);
+			eb_debug(DBG_CORE,
+				"Ayttm: Esd play file failed with code %d\n",
+				errno);
 		}
-	}	
+	}
 	return esd_stat;
 }
 
@@ -278,7 +284,7 @@ static int play_esd_file(gchar *soundfile)
 	return FALSE;
 }
 
-#endif	/* ESD_SOUND */
+#endif				/* ESD_SOUND */
 
 // *** ARTS Support ***
 // Comments/Questions -> sebastian.held@gmx.de
@@ -288,7 +294,9 @@ static int test_arts()
 {
 	int err;
 	if ((err = arts_init()) != 0) {
-		eb_debug(DBG_CORE, "WARNING (NO ERROR!):\ncan_play_arts(): arts_init() failed: %s\nIs artsd running?\n", arts_error_text( err ));
+		eb_debug(DBG_CORE,
+			"WARNING (NO ERROR!):\ncan_play_arts(): arts_init() failed: %s\nIs artsd running?\n",
+			arts_error_text(err));
 		return FALSE;
 	}
 	return TRUE;
@@ -296,34 +304,37 @@ static int test_arts()
 
 static int can_play_arts()
 {
-    
+
 #ifndef ARTS_FREE_IS_BROKEN
 	return test_arts();
 #else
-	pid_t childpid; 
+	pid_t childpid;
 	int childstatus;
 	int ret = -1;
 
 	childpid = fork();
 
-	if(childpid==0)
+	if (childpid == 0)
 		/* Child - do test and exit with result */
-		exit(test_arts() ? 0 : 1);
-    	else if(childpid==-1) {
-		fprintf(stderr,"test_arts(): Failed at fork(), errno=%d\n", errno);
+		exit(test_arts()? 0 : 1);
+	else if (childpid == -1) {
+		fprintf(stderr, "test_arts(): Failed at fork(), errno=%d\n",
+			errno);
 		return FALSE;
 	} else {
-		if( (ret=waitpid(-1, &childstatus, 0) == -1)) {
-			fprintf(stderr,"test_arts(): Failed at wait(), errno=%d\n", errno);
+		if ((ret = waitpid(-1, &childstatus, 0) == -1)) {
+			fprintf(stderr,
+				"test_arts(): Failed at wait(), errno=%d\n",
+				errno);
 			perror("waitpid");
 			return FALSE;
 		}
 
-		if( WEXITSTATUS(childstatus)==0 ) {
-		    return TRUE;
+		if (WEXITSTATUS(childstatus) == 0) {
+			return TRUE;
 		}
-    	}
-	return FALSE;	
+	}
+	return FALSE;
 #endif
 }
 
@@ -339,46 +350,59 @@ static int play_arts_file(gchar *soundfile)
 	arts_stream_t artsStream;
 	int frameSize, channelCount, sampleFormat, sampleWidth, err, susperr;
 	double sampleRate;
-	char * buf;
+	char *buf;
 
 #ifdef ARTS_FREE_IS_BROKEN
 	/* We have to init every time */
 	if ((err = arts_init()) != 0) {
-		eb_debug(DBG_CORE, "WARNING (NO ERROR!):\ncan_play_arts(): arts_init() failed: %s\nIs artsd running?\n", arts_error_text( err ));
+		eb_debug(DBG_CORE,
+			"WARNING (NO ERROR!):\ncan_play_arts(): arts_init() failed: %s\nIs artsd running?\n",
+			arts_error_text(err));
 		return FALSE;
 	}
 #endif
-    
-	fd = afOpenFile( soundfile, "r", NULL );
+
+	fd = afOpenFile(soundfile, "r", NULL);
 	if (fd == AF_NULL_FILEHANDLE) {
-		eb_debug(DBG_CORE, "play_arts_file(): Cannot open file %s\n", soundfile);
+		eb_debug(DBG_CORE, "play_arts_file(): Cannot open file %s\n",
+			soundfile);
 		return FALSE;
 	}
-	frameCount = afGetFrameCount( fd, AF_DEFAULT_TRACK );
-	frameSize = afGetFrameSize( fd, AF_DEFAULT_TRACK, 1 );
-	channelCount = afGetChannels( fd, AF_DEFAULT_TRACK );
-	sampleRate = afGetRate( fd, AF_DEFAULT_TRACK );
-	afGetSampleFormat( fd, AF_DEFAULT_TRACK, &sampleFormat, &sampleWidth );
-	eb_debug(DBG_CORE, "play_arts_file(): frameCount: %d\nframeSize: %i\nchannelCount: %i\nsampleRate: %.2f\n", (int) frameCount, frameSize, channelCount, sampleRate );
+	frameCount = afGetFrameCount(fd, AF_DEFAULT_TRACK);
+	frameSize = afGetFrameSize(fd, AF_DEFAULT_TRACK, 1);
+	channelCount = afGetChannels(fd, AF_DEFAULT_TRACK);
+	sampleRate = afGetRate(fd, AF_DEFAULT_TRACK);
+	afGetSampleFormat(fd, AF_DEFAULT_TRACK, &sampleFormat, &sampleWidth);
+	eb_debug(DBG_CORE,
+		"play_arts_file(): frameCount: %d\nframeSize: %i\nchannelCount: %i\nsampleRate: %.2f\n",
+		(int)frameCount, frameSize, channelCount, sampleRate);
 
-	artsStream = arts_play_stream( sampleRate, sampleWidth, channelCount, "EVERYBUDDY" );
-	buf = (char *) malloc( BUFFERED_FRAME_COUNT * frameSize );
-	count = afReadFrames( fd, AF_DEFAULT_TRACK, buf, BUFFERED_FRAME_COUNT );
+	artsStream =
+		arts_play_stream(sampleRate, sampleWidth, channelCount,
+		"EVERYBUDDY");
+	buf = (char *)malloc(BUFFERED_FRAME_COUNT * frameSize);
+	count = afReadFrames(fd, AF_DEFAULT_TRACK, buf, BUFFERED_FRAME_COUNT);
 	do {
-		err = arts_write( artsStream, buf, count * frameSize );
-		eb_debug(DBG_CORE, "count = %d\n", (int) count);
-		eb_debug(DBG_CORE, "play_arts_file(): written bytes in artsStream: %i\n", err );
-		if(err < 0)
-			eb_debug(DBG_CORE, "arts_write error: %s\n", arts_error_text( err ) );
-	} while ((count = afReadFrames( fd, AF_DEFAULT_TRACK, buf, BUFFERED_FRAME_COUNT)) && (err >= 0));
-	free( buf );
-	arts_close_stream( artsStream );
+		err = arts_write(artsStream, buf, count * frameSize);
+		eb_debug(DBG_CORE, "count = %d\n", (int)count);
+		eb_debug(DBG_CORE,
+			"play_arts_file(): written bytes in artsStream: %i\n",
+			err);
+		if (err < 0)
+			eb_debug(DBG_CORE, "arts_write error: %s\n",
+				arts_error_text(err));
+	} while ((count =
+			afReadFrames(fd, AF_DEFAULT_TRACK, buf,
+				BUFFERED_FRAME_COUNT)) && (err >= 0));
+	free(buf);
+	arts_close_stream(artsStream);
 
-	afCloseFile( fd );
+	afCloseFile(fd);
 	susperr = arts_suspend();
-	if(susperr < 0)
-	        eb_debug(DBG_CORE, "arts_suspend error: %s\n", arts_error_text( err ) );
-    return (err>=0);
+	if (susperr < 0)
+		eb_debug(DBG_CORE, "arts_suspend error: %s\n",
+			arts_error_text(err));
+	return (err >= 0);
 }
 #else
 static int can_play_arts()
@@ -394,9 +418,9 @@ static int play_arts_file(gchar *soundfile)
 {
 	return FALSE;
 }
-#endif	/* ARTS_SOUND */
+#endif				/* ARTS_SOUND */
 
-static char* auscale(char* infile, char*outfile, float scaling)
+static char *auscale(char *infile, char *outfile, float scaling)
 {
 #ifndef __MINGW32__
 	FILE *fd_in = NULL;
@@ -405,80 +429,88 @@ static char* auscale(char* infile, char*outfile, float scaling)
 	size_t bytes_read = 0;
 	size_t io_bytes = 0;
 
-	typedef struct
-	{
+	typedef struct {
 		/* NOTE: THE GUINT32 VALUES BELOW ARE IN THE FILE AS BIG-ENDIAN FORMAT !!!! */
-		guchar  magic[4];  /* magic number '.snd' */
-		guint32 dataloc;    /* offset to start of data */
-		guint32 datasize;   /* num bytes of data */
-		guint32 dataformat; /* data format code */
-		guint32 samplerate; /* sampling rate */
-		guint32 channelcount; /* num of channels */
-		guchar  info;         /* null terminated id string (variable length) */
+		guchar magic[4];	/* magic number '.snd' */
+		guint32 dataloc;	/* offset to start of data */
+		guint32 datasize;	/* num bytes of data */
+		guint32 dataformat;	/* data format code */
+		guint32 samplerate;	/* sampling rate */
+		guint32 channelcount;	/* num of channels */
+		guchar info;	/* null terminated id string (variable length) */
 	} SNDStruct;
 
-	SNDStruct auheader; /* first 28 bytes of .au header */
-	const unsigned int	mapLen = 256;
-	unsigned int		x = 0;
-	guchar	buf;
-	guchar	buf2[mapLen];
-	guchar	map[mapLen]; /* 8-bit mapping */
-
+	SNDStruct auheader;	/* first 28 bytes of .au header */
+	const unsigned int mapLen = 256;
+	unsigned int x = 0;
+	guchar buf;
+	guchar buf2[mapLen];
+	guchar map[mapLen];	/* 8-bit mapping */
 
 	if (scaling == 0.0)
-		return(infile);  /* save time */
+		return (infile);	/* save time */
 
 	if ((fd_in = fopen(infile, "rb")) == NULL) {
-		fprintf(stderr,"Failed opening infile %s, errno=%d\n",infile, errno);
-		return(infile);
+		fprintf(stderr, "Failed opening infile %s, errno=%d\n", infile,
+			errno);
+		return (infile);
 	}
 
 	/* see if this is .au file, if not then get out */
-	if ((io_bytes = fread((guchar *)&auheader, sizeof(guchar), sizeof(auheader), fd_in)) != 28) {
+	if ((io_bytes = fread((guchar *)&auheader, sizeof(guchar),
+				sizeof(auheader), fd_in)) != 28) {
 		fclose(fd_in);
-		fprintf(stderr,"Auscale - header read failed\n");
-		return(infile);
+		fprintf(stderr, "Auscale - header read failed\n");
+		return (infile);
 	}
 
-	if (strncmp((const char *)auheader.magic,".snd",4)) {
-		eb_debug(DBG_CORE, "Not .au file,file type=%X%X%X%X\n",auheader.magic[0],auheader.magic[1],auheader.magic[2],auheader.magic[3]);
+	if (strncmp((const char *)auheader.magic, ".snd", 4)) {
+		eb_debug(DBG_CORE, "Not .au file,file type=%X%X%X%X\n",
+			auheader.magic[0], auheader.magic[1], auheader.magic[2],
+			auheader.magic[3]);
 		fclose(fd_in);
-		return(infile);
+		return (infile);
 	}
 
 	x = GUINT32_FROM_BE(auheader.dataformat);
 
-	if (x!=1) /* only want ulaw-8 format files */ {
-		eb_debug(DBG_CORE, "Not .au file,file type=%X%X%X%X\n",auheader.magic[0],auheader.magic[1],auheader.magic[2],auheader.magic[3]);
+	if (x != 1) {		/* only want ulaw-8 format files */
+		eb_debug(DBG_CORE, "Not .au file,file type=%X%X%X%X\n",
+			auheader.magic[0], auheader.magic[1], auheader.magic[2],
+			auheader.magic[3]);
 		fclose(fd_in);
-		return(infile);
+		return (infile);
 	}
 
-	header_size= GUINT32_FROM_BE(auheader.dataloc); /* get offset to start of data */
+	header_size = GUINT32_FROM_BE(auheader.dataloc);	/* get offset to start of data */
 	/* file is right type, reset to start */
 	rewind(fd_in);
 
 	if ((fd_out = fopen(outfile, "w+b")) == NULL) {
-		fprintf(stderr,"Failed opening outfile %s, errno=%d\n",outfile, errno);
+		fprintf(stderr, "Failed opening outfile %s, errno=%d\n",
+			outfile, errno);
 		fclose(fd_in);
-		return(infile);
+		return (infile);
 	}
 
-	eb_debug(DBG_CORE, "Scaling = %f dB\n",scaling);
-	scaling = pow(10.0,scaling/20.0);
+	eb_debug(DBG_CORE, "Scaling = %f dB\n", scaling);
+	scaling = pow(10.0, scaling / 20.0);
+
+	/* Build mapping */
+	for (x = 0; x < mapLen; x++)
+		map[x] = linear2ulaw(scaling * _af_ulaw2linear(x));
 
-	    /* Build mapping */
-	for (x=0; x<mapLen ; x++)
-		map[x]=linear2ulaw(scaling*_af_ulaw2linear(x));
-  
 	/* Shift the .au header 
 	 * copy the .au header 
 	 * Note: There are unusual situations when the 'info' field is VERY
 	 * large and the start of data can therefore be larger than buf2.
 	 * The following 'while' statement takes care of that problem. */
-	while(header_size >= (guint32)sizeof(buf2)) {
-		if ((io_bytes = fread(buf2, sizeof(guchar), sizeof(buf2), fd_in)) == sizeof(buf2)) {
-			if ((io_bytes = fwrite(buf2, sizeof(guchar), sizeof(buf2), fd_out)) != sizeof(buf2)) {
+	while (header_size >= (guint32) sizeof(buf2)) {
+		if ((io_bytes = fread(buf2, sizeof(guchar), sizeof(buf2),
+					fd_in)) == sizeof(buf2)) {
+			if ((io_bytes = fwrite(buf2, sizeof(guchar),
+						sizeof(buf2),
+						fd_out)) != sizeof(buf2)) {
 				eb_debug(DBG_CORE, "error copying au file");
 				fclose(fd_out);
 				fclose(fd_in);
@@ -492,12 +524,14 @@ static char* auscale(char* infile, char*outfile, float scaling)
 		}
 
 		/* calc remaining amount of header */
-		header_size -= (guint32)sizeof(buf2);
+		header_size -= (guint32) sizeof(buf2);
 	}
 
 	/* copy rest of header (or in most cases - all of it) */
-	if ((io_bytes = fread(buf2, sizeof(guchar), header_size, fd_in)) == header_size) {
-		if ((io_bytes = fwrite(buf2, sizeof(guchar), header_size, fd_out)) != header_size) {
+	if ((io_bytes = fread(buf2, sizeof(guchar), header_size,
+				fd_in)) == header_size) {
+		if ((io_bytes = fwrite(buf2, sizeof(guchar), header_size,
+					fd_out)) != header_size) {
 			eb_debug(DBG_CORE, "error copying au file");
 			fclose(fd_out);
 			fclose(fd_in);
@@ -507,12 +541,12 @@ static char* auscale(char* infile, char*outfile, float scaling)
 		eb_debug(DBG_CORE, "error copying au file");
 		fclose(fd_in);
 		fclose(fd_out);
-		return(infile);
+		return (infile);
 	}
 
 	/* Write the mapped data out */
-	while((bytes_read = fread( &buf, sizeof(guchar), 1, fd_in)) > 0)
-		fwrite(map+buf, sizeof(guchar), 1, fd_out);
+	while ((bytes_read = fread(&buf, sizeof(guchar), 1, fd_in)) > 0)
+		fwrite(map + buf, sizeof(guchar), 1, fd_out);
 
 	fclose(fd_in);
 	fclose(fd_out);
@@ -521,8 +555,6 @@ static char* auscale(char* infile, char*outfile, float scaling)
 	return outfile;
 }
 
-
-
 /* file_ok 
  *
  * This routine test to see if file can be found and accessed
@@ -538,18 +570,23 @@ static char* auscale(char* infile, char*outfile, float scaling)
 static gboolean file_ok(gchar *soundfile)
 {
 	gchar message[1024];
-    
+
 	if (access(soundfile, R_OK) == -1) {
-      /* find and report the error */
+		/* find and report the error */
 		switch (errno) {
 		case ENOENT:
-			g_snprintf(message, 1024, "Sound file \'%s\', Not Found", soundfile);
+			g_snprintf(message, 1024,
+				"Sound file \'%s\', Not Found", soundfile);
 			break;
 		case EACCES:
-			g_snprintf(message, 1024, "Sound file \'%s\', Access Not Allowed", soundfile);
+			g_snprintf(message, 1024,
+				"Sound file \'%s\', Access Not Allowed",
+				soundfile);
 			break;
 		default:
-			g_snprintf(message, 1024, "Error in opening sound file \'%s\', error code = %d", soundfile, errno);
+			g_snprintf(message, 1024,
+				"Error in opening sound file \'%s\', error code = %d",
+				soundfile, errno);
 		}
 		eb_debug(DBG_CORE, "%s", message);
 		return FALSE;
@@ -557,69 +594,70 @@ static gboolean file_ok(gchar *soundfile)
 	return TRUE;
 }
 
-
 void playsoundfile(gchar *soundfile)
 {
-    
-#ifdef _WIN32
-	if(!play_soundfile)
-        return;
 
-	if (!file_ok(soundfile)) 
+#ifdef _WIN32
+	if (!play_soundfile)
 		return;
 
-	PlaySound(soundfile,NULL,SND_FILENAME|SND_SYNC);
+	if (!file_ok(soundfile))
+		return;
+
+	PlaySound(soundfile, NULL, SND_FILENAME | SND_SYNC);
 	return;
 #endif
 #ifndef __MINGW32__
 	gint pid;
 
-	if(!play_soundfile)
+	if (!play_soundfile)
 		return;
 
-	if (!file_ok(soundfile)) 
+	if (!file_ok(soundfile))
 		return;
 
 	pid = fork();
 	if (pid < 0) {
-	    fprintf(stderr, "in playsoundfile(), fork failed!\n");
-	    return;
+		fprintf(stderr, "in playsoundfile(), fork failed!\n");
+		return;
 	} else if (pid == 0) {
 		/* we're the child process, play the sound... */
-		if(fGetLocalPref("SoundVolume") != 0.0) {
+		if (fGetLocalPref("SoundVolume") != 0.0) {
 			gchar tmp_soundfile[9] = "ebXXXXXX";
-			
-			if (mkstemp(tmp_soundfile) == -1) /* create name for auscale */ {
-				fprintf(stderr, "in playsoundfile(), mkstemp failed!\n");
+
+			if (mkstemp(tmp_soundfile) == -1) {	/* create name for auscale */
+				fprintf(stderr,
+					"in playsoundfile(), mkstemp failed!\n");
 				return;
 			}
 
-			soundfile = auscale(soundfile,tmp_soundfile,fGetLocalPref("SoundVolume"));
+			soundfile =
+				auscale(soundfile, tmp_soundfile,
+				fGetLocalPref("SoundVolume"));
 
 			play_soundfile(soundfile);
 
 			if (unlink(tmp_soundfile))
-				fprintf(stderr, "in playsoundfile(), unlink failed!\n");
+				fprintf(stderr,
+					"in playsoundfile(), unlink failed!\n");
 		} else {
 			play_soundfile(soundfile);
 		}
 
 		_exit(0);
 	} else {
-	    /* We're the parent process... */
-	    eb_timeout_add(100, clean_pid, NULL);
+		/* We're the parent process... */
+		eb_timeout_add(100, clean_pid, NULL);
 	}
-#endif 
+#endif
 }
 
-
-
 void play_sound(int sound)
 {
-	if ( iGetLocalPref("do_no_sound_when_away") && is_away )
+	if (iGetLocalPref("do_no_sound_when_away") && is_away)
 		return;
-		
-	switch(sound)  {
+
+	switch (sound) {
 	case SOUND_BUDDY_AWAY:
 		playsoundfile(cGetLocalPref("BuddyAwayFilename"));
 		break;
@@ -643,24 +681,22 @@ void play_sound(int sound)
 
 void sound_init()
 {
-	if(can_play_arts()) {
-		eb_debug(DBG_CORE,"Using arts sound\n");
+	if (can_play_arts()) {
+		eb_debug(DBG_CORE, "Using arts sound\n");
 		play_soundfile = play_arts_file;
 		shutdown_sounddrv = arts_shutdown;
-	}
-	else if(can_play_esd()) {
-		eb_debug(DBG_CORE,"Using esd sound\n");
+	} else if (can_play_esd()) {
+		eb_debug(DBG_CORE, "Using esd sound\n");
 		play_soundfile = play_esd_file;
 		shutdown_sounddrv = NULL;
 	}
 	/* handle sound direct to /dev/audio */
 	else if (can_play_audio()) {
-		eb_debug(DBG_CORE,"Using raw audio\n");
+		eb_debug(DBG_CORE, "Using raw audio\n");
 		play_soundfile = play_audio;
 		shutdown_sounddrv = NULL;
-	}
-	else {
-		eb_debug(DBG_CORE,"Sound not available\n");
+	} else {
+		eb_debug(DBG_CORE, "Sound not available\n");
 		play_soundfile = NULL;
 		shutdown_sounddrv = NULL;
 	}
@@ -668,6 +704,6 @@ void sound_init()
 
 void sound_shutdown()
 {
-	if(shutdown_sounddrv != NULL)
+	if (shutdown_sounddrv != NULL)
 		shutdown_sounddrv();
 }
